==> dictionary-service-local-2.2.0.2-Release-sources.jar: com/bizunited/platform/dictionary/service/local/entity/DictCategoryEntity.java <==
package com.bizunited.platform.dictionary.service.local.entity;

import com.bizunited.platform.common.entity.UuidEntity;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import java.util.Date;
import java.util.Set;

/**
 * DictCategoryRepository
 * @description: 字典分类
 * @author: yanwe
 * @date: 11/Jun/2019 16:47
 */
@ApiModel(value = "DictCategoryRepository", description = "字典分类")
@Entity
@Table(name = "engine_category_dict")
@org.hibernate.annotations.Table(appliesTo = "engine_category_dict" , comment = "字典分类")
public class DictCategoryEntity extends UuidEntity {

  private static final long serialVersionUID = 8118797910731290828L;
  /** 字典分类编码 * */
  @Column(name = "cate_code", length = 64, nullable = false, unique = true, columnDefinition = "varchar(64) COMMENT '字典分类编码'")
  @ApiModelProperty(name = "cateCode", value = "字典分类编码", required = true)
  @SaturnColumn(description = "字典分类编码")
  private String cateCode;
  /** 字典分类名称. * */
  @Column(name = "cate_name", length = 64, nullable = false, columnDefinition = "varchar(64) COMMENT '字典分类名称'")
  @ApiModelProperty(name = "cateName", value = "字典分类名称", required = true)
  @SaturnColumn(description = "字典分类名称")
  private String cateName;
  /** 字典分类描述. * */
  @Column(name = "cate_desc", length = 64, columnDefinition = "varchar(64) COMMENT '字典分类描述'")
  @ApiModelProperty(name = "cateDesc", value = "字典分类描述")
  @SaturnColumn(description = "字典分类描述")
  private String cateDesc;
  /** 父级分组 */
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "parent_id", columnDefinition = "varchar(255) COMMENT '父级分组'")
  @SaturnColumn(description = "父级分类")
  private DictCategoryEntity parentCategory;
  /** 子级分组 */
  @OneToMany(fetch = FetchType.LAZY, mappedBy = "parentCategory")
  @SaturnColumn(description = "子级组织")
  @OrderBy("createTime")
  private Set<DictCategoryEntity> childCategory;
  /** 该分组下所有字典 */
  @OrderBy("createTime")
  @OneToMany(fetch = FetchType.LAZY, mappedBy = "category")
  @SaturnColumn(description = "该分组下所有字典")
  private Set<DictEntity> dicts;

  /**
   * 创建人
   */
  @ApiModelProperty(name = "createAccount", value = "创建人", required = true)
  @SaturnColumn(description = "创建人")
  @Column(name="create_account" , nullable=false, columnDefinition = "varchar(255) COMMENT '创建人'")
  private String createAccount;

  /**
   * 最后修改人
   */
  @ApiModelProperty(name = "modifyAccount", value = "最后修改人", required = true)
  @Column(name="modify_account", nullable = false, columnDefinition = "varchar(255) COMMENT '最后修改人'")
  @SaturnColumn(description = "最后更新人")
  private String modifyAccount;

  /** 创建时间 */
  @ApiModelProperty(name = "createTime", value = "创建时间", required = true)
  @Column(name = "create_time", nullable = false, columnDefinition = "datetime COMMENT '创建时间'")
  @SaturnColumn(description = "创建时间")
  private Date createTime;
  /** 最后更新时间 */
  @ApiModelProperty(name = "modifyTime", value = "最后更新时间", required = true)
  @Column(name = "modify_time" , columnDefinition = "datetime COMMENT '最后更新时间'")
  @SaturnColumn(description = "最后更新时间")
  private Date modifyTime;

  public String getCateCode() {
    return cateCode;
  }
  public void setCateCode(String cateCode) {
    this.cateCode = cateCode;
  }
  public String getCateDesc() {
    return cateDesc;
  }
  public void setCateDesc(String cateDesc) {
    this.cateDesc = cateDesc;
  }
  public DictCategoryEntity getParentCategory() {
    return parentCategory;
  }
  public void setParentCategory(DictCategoryEntity parentCategory) {
    this.parentCategory = parentCategory;
  }
  public Set<DictCategoryEntity> getChildCategory() {
    return childCategory;
  }
  public void setChildCategory(Set<DictCategoryEntity> childCategory) {
    this.childCategory = childCategory;
  }
  public Set<DictEntity> getDicts() {
    return dicts;
  }
  public void setDicts(Set<DictEntity> dicts) {
    this.dicts = dicts;
  }

  public String getCateName() {
    return cateName;
  }

  public void setCateName(String cateName) {
    this.cateName = cateName;
  }

  public String getCreateAccount() {
    return createAccount;
  }

  public void setCreateAccount(String createAccount) {
    this.createAccount = createAccount;
  }

  public String getModifyAccount() {
    return modifyAccount;
  }

  public void setModifyAccount(String modifyAccount) {
    this.modifyAccount = modifyAccount;
  }

  public Date getCreateTime() {
    return createTime;
  }

  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  public Date getModifyTime() {
    return modifyTime;
  }

  public void setModifyTime(Date modifyTime) {
    this.modifyTime = modifyTime;
  }
}

==> dictionary-service-local-2.2.1.7-Release-sources.jar: com/bizunited/platform/dictionary/service/local/entity/DictCategoryEntity.java <==
package com.bizunited.platform.dictionary.service.local.entity;

import com.bizunited.platform.common.entity.UuidEntity;
import com.bizunited.platform.common.util.ApplicationContextUtils;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import java.util.Date;
import java.util.Set;

/**
 * DictCategoryRepository
 * @description: 字典分类
 * @author: yanwe
 * @date: 11/Jun/2019 16:47
 */
@ApiModel(value = "DictCategoryRepository", description = "字典分类")
@Entity
@Table(name = "engine_category_dict")
@org.hibernate.annotations.Table(appliesTo = "engine_category_dict" , comment = "字典分类")
public class DictCategoryEntity extends UuidEntity {

  private static final long serialVersionUID = 8118797910731290828L;
  /** 字典分类编码 * */
  @Column(name = "cate_code", length = 64, nullable = false, unique = true, columnDefinition = "varchar(64) COMMENT '字典分类编码'")
  @ApiModelProperty(name = "cateCode", value = "字典分类编码", required = true)
  @SaturnColumn(description = "字典分类编码")
  private String cateCode;
  /** 字典分类名称. * */
  @Column(name = "cate_name", length = 64, nullable = false, columnDefinition = "varchar(64) COMMENT '字典分类名称'")
  @ApiModelProperty(name = "cateName", value = "字典分类名称", required = true)
  @SaturnColumn(description = "字典分类名称")
  private String cateName;
  /** 字典分类描述. * */
  @Column(name = "cate_desc", length = 64, columnDefinition = "varchar(64) COMMENT '字典分类描述'")
  @ApiModelProperty(name = "cateDesc", value = "字典分类描述")
  @SaturnColumn(description = "字典分类描述")
  private String cateDesc;
  /** 父级分组 */
  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "parent_id", columnDefinition = "varchar(255) COMMENT '父级分组'")
  @SaturnColumn(description = "父级分类")
  private DictCategoryEntity parentCategory;
  /** 子级分组 */
  @OneToMany(fetch = FetchType.LAZY, mappedBy = "parentCategory")
  @SaturnColumn(description = "子级组织")
  @OrderBy("createTime")
  private Set<DictCategoryEntity> childCategory;
  /** 该分组下所有字典 */
  @OrderBy("createTime")
  @OneToMany(fetch = FetchType.LAZY, mappedBy = "category")
  @SaturnColumn(description = "该分组下所有字典")
  private Set<DictEntity> dicts;

  /**
   * 创建人
   */
  @ApiModelProperty(name = "createAccount", value = "创建人", required = true)
  @SaturnColumn(description = "创建人")
  @Column(name="create_account" , nullable=false, columnDefinition = "varchar(255) COMMENT '创建人'")
  private String createAccount;

  /**
   * 最后修改人
   */
  @ApiModelProperty(name = "modifyAccount", value = "最后修改人", required = true)
  @Column(name="modify_account", nullable = false, columnDefinition = "varchar(255) COMMENT '最后修改人'")
  @SaturnColumn(description = "最后更新人")
  private String modifyAccount;

  /** 创建时间 */
  @ApiModelProperty(name = "createTime", value = "创建时间", required = true)
  @Column(name = "create_time", nullable = false, columnDefinition = "datetime COMMENT '创建时间'")
  @SaturnColumn(description = "创建时间")
  private Date createTime;
  /** 最后更新时间 */
  @ApiModelProperty(name = "modifyTime", value = "最后更新时间", required = true)
  @Column(name = "modify_time" , columnDefinition = "datetime COMMENT '最后更新时间'")
  @SaturnColumn(description = "最后更新时间")
  private Date modifyTime;

  /** 当前项目名工程名*/
  @ApiModelProperty("当前项目名工程名")
  @Column(name="project_name", nullable = false, columnDefinition = "varchar(255) default '' comment '工程名'")
  @SaturnColumn(description = "工程名")
  private String projectName = ApplicationContextUtils.getProjectName();

  public String getProjectName() {
    return projectName;
  }

  public void setProjectName(String projectName) {
    this.projectName = projectName;
  }

  public String getCateCode() {
    return cateCode;
  }
  public void setCateCode(String cateCode) {
    this.cateCode = cateCode;
  }
  public String getCateDesc() {
    return cateDesc;
  }
  public void setCateDesc(String cateDesc) {
    this.cateDesc = cateDesc;
  }
  public DictCategoryEntity getParentCategory() {
    return parentCategory;
  }
  public void setParentCategory(DictCategoryEntity parentCategory) {
    this.parentCategory = parentCategory;
  }
  public Set<DictCategoryEntity> getChildCategory() {
    return childCategory;
  }
  public void setChildCategory(Set<DictCategoryEntity> childCategory) {
    this.childCategory = childCategory;
  }
  public Set<DictEntity> getDicts() {
    return dicts;
  }
  public void setDicts(Set<DictEntity> dicts) {
    this.dicts = dicts;
  }

  public String getCateName() {
    return cateName;
  }

  public void setCateName(String cateName) {
    this.cateName = cateName;
  }

  public String getCreateAccount() {
    return createAccount;
  }

  public void setCreateAccount(String createAccount) {
    this.createAccount = createAccount;
  }

  public String getModifyAccount() {
    return modifyAccount;
  }

  public void setModifyAccount(String modifyAccount) {
    this.modifyAccount = modifyAccount;
  }

  public Date getCreateTime() {
    return createTime;
  }

  public void setCreateTime(Date createTime) {
    this.createTime = createTime;
  }

  public Date getModifyTime() {
    return modifyTime;
  }

  public void setModifyTime(Date modifyTime) {
    this.modifyTime = modifyTime;
  }
}
